//
//  SettingsViewController.swift
//  MapSample
//
//  Created by MasaKentaro on 2016/07/31.
//  Copyright © 2016年 MasaKentaro. All rights reserved.
//

import UIKit
import MapKit

class SettingsViewController: UITableViewController {

    var mapType: MKMapType = MKMapType.standard
    var buildingEnabled: Bool = true
    var pitchEnabled: Bool = true
    var compassEnabled: Bool = true
    var scaleEnabled: Bool = true
    var updatingLocation: Bool = true
    var userLocationEnabled: Bool = true
    
    @IBOutlet weak var mapTypeControl: UISegmentedControl!
    @IBOutlet weak var buildingSwitch: UISwitch!
    @IBOutlet weak var pitchSwitch: UISwitch!
    @IBOutlet weak var compassSwitch: UISwitch!
    @IBOutlet weak var scaleSwitch: UISwitch!
    @IBOutlet weak var updatingLocationSwitch: UISwitch!
    @IBOutlet weak var userLocationSwitch: UISwitch!
    
    override func viewDidLoad() {
        super.viewDidLoad()

        // Uncomment the following line to preserve selection between presentations
        // self.clearsSelectionOnViewWillAppear = false

        // Uncomment the following line to display an Edit button in the navigation bar for this view controller.
        // self.navigationItem.rightBarButtonItem = self.editButtonItem()

        switch mapType {
        case .standard:
            mapTypeControl.selectedSegmentIndex = 0
        case .hybrid:
            mapTypeControl.selectedSegmentIndex = 1
        case .satellite:
            mapTypeControl.selectedSegmentIndex = 2
        default:
            mapTypeControl.selectedSegmentIndex = 0
        }
        
        buildingSwitch.isOn = buildingEnabled
        pitchSwitch.isOn = pitchEnabled
        compassSwitch.isOn = compassEnabled
        scaleSwitch.isOn = scaleEnabled
        updatingLocationSwitch.isOn = updatingLocation
        userLocationSwitch.isOn = userLocationEnabled
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    // MARK: - Table view data source

    /*
    override func tableView(_ tableView: UITableView, cellForRowAt indexPath: IndexPath) -> UITableViewCell {
        let cell = tableView.dequeueReusableCell(withIdentifier: "reuseIdentifier", for: indexPath)

        // Configure the cell...

        return cell
    }
    */

    /*
    // Override to support conditional editing of the table view.
    override func tableView(_ tableView: UITableView, canEditRowAt indexPath: IndexPath) -> Bool {
        // Return false if you do not want the specified item to be editable.
        return true
    }
    */

    /*
    // Override to support editing the table view.
    override func tableView(_ tableView: UITableView, commit editingStyle: UITableViewCellEditingStyle, forRowAt indexPath: IndexPath) {
        if editingStyle == .delete {
            // Delete the row from the data source
            tableView.deleteRows(at: [indexPath], with: .fade)
        } else if editingStyle == .insert {
            // Create a new instance of the appropriate class, insert it into the array, and add a new row to the table view
        }    
    }
    */

    /*
    // Override to support rearranging the table view.
    override func tableView(_ tableView: UITableView, moveRowAt fromIndexPath: IndexPath, to: IndexPath) {

    }
    */

    /*
    // Override to support conditional rearranging of the table view.
    override func tableView(_ tableView: UITableView, canMoveRowAt indexPath: IndexPath) -> Bool {
        // Return false if you do not want the item to be re-orderable.
        return true
    }
    */

    /*
    // MARK: - Navigation

    // In a storyboard-based application, you will often want to do a little preparation before navigation
    override func prepare(for segue: UIStoryboardSegue, sender: AnyObject?) {
        // Get the new view controller using segue.destinationViewController.
        // Pass the selected object to the new view controller.
    }
    */
    
    override func prepare(for segue: UIStoryboardSegue, sender: Any?){
        
        let userDefaults = UserDefaults.standard
        
        userDefaults.set(mapTypeControl.selectedSegmentIndex, forKey: "mapType")
        userDefaults.set(buildingSwitch.isOn, forKey: "buildingEnabled")
        userDefaults.set(pitchSwitch.isOn, forKey: "pitchEnabled")
        userDefaults.set(compassSwitch.isOn, forKey: "compassEnabled")
        userDefaults.set(scaleSwitch.isOn, forKey: "scaleEnabled")
        userDefaults.set(updatingLocationSwitch.isOn, forKey: "updatingLocation")
        userDefaults.set(userLocationSwitch.isOn, forKey: "userLocationEnabled")
        
        userDefaults.synchronize()
        
        let viewController:ViewController = segue.destination as! ViewController
        
        switch mapTypeControl.selectedSegmentIndex {
        case 0:
            viewController.mapType = .standard
        case 1:
            viewController.mapType = .hybrid
        case 2:
            viewController.mapType = .satellite
        default:
            viewController.mapType = .standard
        }
        viewController.buildingEnabled = buildingSwitch.isOn
        viewController.pitchEnabled = pitchSwitch.isOn
        viewController.compassEnabled = compassSwitch.isOn
        viewController.scaleEnabled = scaleSwitch.isOn
        viewController.updatingLocation = updatingLocationSwitch.isOn
        viewController.userLocationEnabled = userLocationSwitch.isOn
        
        viewController.configureMapView()
    }


}
