//
//  ViewController.swift
//  SpeechSample
//
//  Created by MasaKentaro on 2016/08/04.
//  Copyright © 2016年 MasaKentaro. All rights reserved.
//

import UIKit
import AVFoundation

class ViewController: UIViewController {

    var rate: Float = AVSpeechUtteranceDefaultSpeechRate
    var pitchMultiplier: Float = 1.0
    var volume: Float = 1.0
    var preUtteranceDelay: TimeInterval = 0.0

    var speechText: String = "すうぃふと　頑張ります"
    var urlText: String = "https://news.google.co.jp/nwshp"

    @IBOutlet weak var speechTextField: UITextField!
    @IBOutlet weak var webUrlField: UITextField!

    override func viewDidLoad() {
        super.viewDidLoad()
        // Do any additional setup after loading the view, typically from a nib.
        let userDefaults = UserDefaults.standard
        
        userDefaults.register(defaults: ["rate": 0.5])
        userDefaults.register(defaults: ["pitchMultiplier": 1.0])
        userDefaults.register(defaults: ["volume": 1.0])
        userDefaults.register(defaults: ["preUtteranceDelay": 0.0])
        
        rate = userDefaults.float(forKey: "rate")
        pitchMultiplier = userDefaults.float(forKey: "pitchMultiplier")
        volume = userDefaults.float(forKey: "volume")
        preUtteranceDelay = userDefaults.double(forKey: "preUtteranceDelay")
        
        speechTextField.text = speechText
        webUrlField.text = urlText
    }

    override func didReceiveMemoryWarning() {
        super.didReceiveMemoryWarning()
        // Dispose of any resources that can be recreated.
    }

    @IBAction func textSpeechButtonTapped(sender: UIButton) {
        
        guard let text = speechTextField.text else {
            return
        }
        
        let utterance = AVSpeechUtterance(string: text)
        
        utterance.rate = self.rate
        utterance.pitchMultiplier = self.pitchMultiplier
        utterance.volume = self.volume
        utterance.preUtteranceDelay = self.preUtteranceDelay
        
        utterance.voice = AVSpeechSynthesisVoice(language: "ja-JP")
        
        AVSpeechSynthesizer().speak(utterance)
    }
    
    @IBAction func webButtonTapped(sender: UIButton) {
        
        guard let url = webUrlField.text else {
            return
        }
        
        urlText = url
    }

    @IBAction func unwindToTop(segue: UIStoryboardSegue) {
    }
    
    override func shouldPerformSegue(withIdentifier identifier: String?,
                                     sender: Any?) -> Bool {
        
        if identifier == "toWebView" {
            if let text = webUrlField.text {
                if text.isEmpty {
                    return false
                } else {
                    return true
                }
            }
        }
        
        return true
    }
    
    override func prepare(for segue: UIStoryboardSegue, sender: Any?){
        
        if segue.identifier == "toWebView" {
            
            let navigation:UINavigationController =
                segue.destination as! UINavigationController
            let viewController:WebViewController =
                navigation.visibleViewController as! WebViewController
            
            viewController.rate = rate
            viewController.pitchMultiplier = pitchMultiplier
            viewController.volume = volume
            viewController.preUtteranceDelay = preUtteranceDelay
            viewController.urlText = urlText
        }
        
        if segue.identifier == "toSettings" {
            
            let navigation:UINavigationController =
                segue.destination as! UINavigationController
            let viewController:SettingsViewController =
                navigation.visibleViewController as! SettingsViewController
            
            viewController.rate = rate
            viewController.pitchMultiplier = pitchMultiplier
            viewController.volume = volume
            viewController.preUtteranceDelay = preUtteranceDelay
        }
    }
}

